// Contains class definitions
// Copyright (C) 1997 by John P. Weiss
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the Artistic License, included as the file
// "LICENSE" in the source code archive.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
//
// You should have received a copy of the file "LICENSE", containing
// the License John Weiss originally placed this program under.
#include "PixButton.h"



// ***************
//  Here, we define the actual functions



//||||||||||||||||||||||||||||||||||||||||||||||||
//
//  Class PixButton
//
//||||||||||||||||||||||||||||||||||||||||||||||||



// Constructor for the PixButton object.
//
PixButton::PixButton( QWidget *parent ) : QPushButton( parent )
{
  return;
}


// Overloaded constructor for the PixButton object.
//
PixButton::PixButton( QWidget *parent, RawPixData rawdat, float scale
  ) : QPushButton( parent )
{
  bDataInit( rawdat, scale );
}



// Initializes the button's pixmap using a RawPixData structure
//
void PixButton::bDataInit( RawPixData rawdat, float scale )
{
  if(rawdat.fixed)
	{
	scale = 1.0;
	}

  b_pd = new PixData( rawdat, scale );
  
  bRepaint();
}


// Repaints the button
//
void PixButton::bRepaint(void)
{
   b_pd->setColor( foregroundColor(), backgroundColor() );
   b_pm = b_pd->toPixmap();
   setPixmap( b_pm );
   resize( b_pm.size() );
}


// Rescales the button.
//
void PixButton::bRescale( float scale )
{
  if( (b_pd->fixedScale) || (scale == 1.0) )
	{
	return;
	}

  b_pd->rescale( scale );
  bRepaint();
}


//||||||||||||||||||||||||||||||||
//
// End.
//
